#!/usr/bin/env python
import public
import shields

"""
http://shields.io/
version:              https://img.shields.io/pypi/v/Django.svg

License:              https://img.shields.io/pypi/l/Django.svg
Wheel:                https://img.shields.io/pypi/wheel/Django.svg
Format:               https://img.shields.io/pypi/format/Django.svg
pyversions:           https://img.shields.io/pypi/pyversions/Django.svg
Implementation:       https://img.shields.io/pypi/implementation/Django.svg
Status:               https://img.shields.io/pypi/status/Django.svg
"""


class Pypi(shields.Abstract):
    __readme__ = []
    name = None
    link = "https://pypi.org/project/{name}/"
    path = "pypi/{cls}/{name}.svg"

    def __init__(self, name, **kwargs):
        self.name = name
        self.update(kwargs)

    @property
    def cls(self):
        return self.__class__.__name__.lower()


@public.add
class V(Pypi):
    """pypi Version badge"""


@public.add
class L(Pypi):
    """pypi License badge"""


class Wheel(Pypi):
    pass


class Format(Pypi):
    pass


@public.add
class Pyversions(Pypi):
    """pypi pyversions badge"""


class Implementation(Pypi):
    pass


class Status(Pypi):
    pass



#!/usr/bin/env python
import public
import shields

"""

"""


class Npm(shields.Abstract):
    name = None
    link = "https://www.npmjs.com/package/{name}"

    def __init__(self, name, **kwargs):
        self.name = name
        self.update(kwargs)


@public.add
class V(Npm):
    """npm Version badge"""
    path = "npm/v/{name}.svg"
    __readme__ = []



#!/usr/bin/env python
try:
    from urllib import urlencode  # python2
except ImportError:
    from urllib.parse import urlencode  # python3
import badge
import public

"""
http://shields.io/

The following styles are available (flat is the default as of Feb 1st 2015)
"""
STYLES = ["plastic", "flat", "flat-square", "for-the-badge", "social"]
"""without 'link'"""
PARAMETERS = ["style", "label", "logo", "logoWidth", "colorA", "colorB", "maxAge", "longCache"]


class Abstract(badge.Badge):
    @property
    def parameters(self):
        parameters = dict()
        for key in PARAMETERS:
            value = getattr(self, key, None)
            if value:
                parameters[key] = value
        return parameters

    @property
    def query(self):
        return urlencode(self.parameters)

    @property
    def image(self):
        image = "https://img.shields.io/%s" % self.path
        if self.parameters:
            return "%s?%s" % (image, self.query)
        return image



#!/usr/bin/env python
import shields

"""
http://shields.io/
https://img.shields.io/badge/<SUBJECT>-<STATUS>-<COLOR>.svg

brightgreen, green, yellowgreen, yellow, orange, red, lightgrey, blue
"""


class Badge(shields.Abstract):
    """shields.io custom Badge"""
    __readme__ = ["subject", "status", "color"]
    path = "badge/{subject}-{status}-{color}.svg"
    subject = None
    status = None
    color = "green"
